# ================================================================
# Examples of the documentation of Model DPSDT:
# DPSDT-1: Source monitoring with two signals
#
# Data from Hilford et al. (2002)
# Date of creation: August, 2013
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-DPSDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))


# DATA: HILFORD ET AL. (2002), Exp.1
data.1 <- c(264, 133, 159, 116,  80,  33,			# Male voice 
 	       25,  62, 105, 128, 145, 294)			# Female voice


# DATA: HILFORD ET AL. (2002), Exp.2
data.2 <- c(1358, 550, 701, 585, 466,  300,		# Male
 	       278, 477, 598, 614, 589, 1404)		# Female


# DATA: HILFORD ET AL. (2002), Exp.3
data.3 <- c(1313, 538, 524, 529, 363,  333,		# Top 
 	       348, 356, 455, 552, 510, 1379)		# Bottom


cat("\n------------------------------------------------------------------------------------\n")
cat(" DPSDT: Hilford et al. (2002), Exp.1: Identical recollection probabilities")
cat("\n------------------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 2, restriction = "standard-2-eq")
Opti1.Obj <- SDT.Estimate(data = data.1, n = cfg, Model.Id = "DPSDT", test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" DPSDT: Hilford et al. (2002), Exp.2: Identical recollection probabilities")
cat("\n------------------------------------------------------------------------------------\n")
Opti2.Obj <- SDT.Estimate(data = data.2, n = cfg, Model.Id = "DPSDT", test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)
print(Stat2.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" DPSDT: Hilford et al. (2002), Exp.3: Identical recollection probabilities")
cat("\n------------------------------------------------------------------------------------\n")
Opti3.Obj <- SDT.Estimate(data = data.3, n = cfg, Model.Id = "DPSDT", test = T)
Stat3.Obj <- SDT.Statistics(Opti3.Obj)
print(Stat3.Obj)