# ================================================================
# Examples of the documentation of Model DPSDT:
# DPSDT-2.1: Modeling Associative Recognition
#
# Data from Kelley and Wixted, Exp.1
# Date of creation: November, 2013
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-DPSDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))


# DATA OF KELLEY & WIXTED (2001), Experiment 1

data <- c(198, 148, 210,  85,  49,  30,   # Weak   Items, rearranged
	     72,  91, 167,  71,  71, 248,	# Weak   Items, intact
	    305, 110, 126,  79,  45,  55,	# Strong Items, rearranged
	     19,  23,  36,  57,  81, 504) 	# Strong Items, intact

cat("\n-----------------------------------------------------------------------\n")
cat(" DPSDT 1: Associative recognition (Data from Kelley and Wixted, Exp.1:\n")
cat("          restriction = \"standard-pairs-eq\"\n")
cat("          recollection[1] = 0, recollection[3] = 0\n") 
cat("          stddev[2] = stddev[4]")
cat("\n-----------------------------------------------------------------------\n")
cfg <- list(n.sdt = 4, restriction = "standard-pairs-eq", rec.pos = c(1, 6, 1, 6))

Opti1.Obj <- SDT.Estimate(data = data, n = cfg, Model.Id = "DPSDT", test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n-----------------------------------------------------------------------\n")
cat(" DPSDT-2: Associative recognition (Data from Kelley and Wixted, Exp.1:\n")
cat("          restriction = \"standard-pairs\"\n")
cat("          recollection[1] = 0, recollection[3] = 0\n") 
cat("          stddev[1] = stddev[2] = stddev[3] = stddev[4]")
cat("\n-----------------------------------------------------------------------\n")
cfg <- list(n.sdt = 4, restriction = "standard-pairs", rec.pos = c(1, 6, 1, 6))

Opti2.Obj <- SDT.Estimate(data = data, n = cfg, Model.Id = "DPSDT", test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)
print(Stat2.Obj)