# ================================================================
# Examples of the documentation of Model DPSDT:
# DPSDT-2.2: Modeling Associative Recognition
#
# Data from Kelley and Wixted, Exp.2
# Date of creation: November, 2013
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-DPSDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# DATA OF KELLEY & WIXTED (2001), Experiment 2
data <- c(879, 553, 345,  61,  54,  28,	# Exp.2: Lure items
	    179, 109,  82,  45,  28,  37,   # Exp.2: Weak   Items, rearranged
	     81,  69,  62,  31,  37, 200,	# Exp.2: Weak   Items, intact
	    215,  82,  60,  31,  31,  61,	# Exp.2: Strong Items, rearranged
 	     21,  24,  33,  21,  33, 348)	# Exp.2: Strong Items, intact

cat("\n-----------------------------------------------------------------------\n")
cat(" DPSDT 1: Associative recognition (Data from Kelley and Wixted, Exp.2:\n")
cat("          restriction = \"standard-lure-pairs-eq\"\n")
cat("          - Distribution 1 = N(0,1) [Lure]\n")
cat("          - recollection[2] = 0, recollection[4] = 0\n") 
cat("          - stddev[2] = stddev[3] = stddev[4] = stddev[5]")
cat("\n-----------------------------------------------------------------------\n")
cfg <- list(n.sdt = 5, restriction = "standard-lure-pairs-eq", rec.pos = c(1, 1, 6, 1, 6))
Opti1.Obj <- SDT.Estimate(data = data, Model.Id = "DPSDT", n = cfg, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n-----------------------------------------------------------------------\n")
cat(" DPSDT 2: Associative recognition (Data from Kelley and Wixted, Exp.2:\n")
cat("          restriction = \"standard-lure-pairs-eq\"\n")
cat("          - Distribution 1 = N(0,1) [Lure]\n")
cat("          - recollection[2] = 0, recollection[4] = 0\n") 
cat("          - stddev[2] = stddev[3] = stddev[4] = stddev[5]\n")
cat("          - p.rec[4] = p.rec[6]")
cat("\n-----------------------------------------------------------------------\n")
# Identity constraint: Recollection parameter of Model 4 (#17) = recollection parameter of Model 6 (#33)
ident <- matrix(c(17,
                  33), nr = 2, byrow = T)
Opti2.Obj <- SDT.Estimate(data = data, Model.Id = "DPSDT", n = cfg, ident = ident, test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)
print(Stat2.Obj)


cat("\n-----------------------------------------------------------------------\n")
cat(" DPSDT 3: Associative recognition (Data from Kelley and Wixted, Exp.2:\n")
cat("          restriction = \"standard-lure-pairs-eq\"\n")
cat("          - Distribution 1 = N(0,1) [Lure]\n")
cat("          - recollection[2] = 0, recollection[4] = 0\n") 
cat("          - stddev[2] = stddev[3] = stddev[4] = stddev[5]\n")
cat("          - p.rec[6]")
cat("\n-----------------------------------------------------------------------\n")
# Identity constraint: Recollection parameter of Model (#33) = 0
fixed <- matrix(c( 0,
                  33), nr = 2, byrow = T)
Opti3.Obj <- SDT.Estimate(data = data, Model.Id = "DPSDT", n = cfg, fixed = fixed, test = T)
Stat3.Obj <- SDT.Statistics(Opti3.Obj)
print(Stat3.Obj)
