# ======================================================================
# Examples of the documentation of Model DPSDT:
# DPSDT-3: Displaying the parameter information for different types of 
#          restrictions
#
# Date of creation: NOVEMBER, 2013
# Author: Siegfried Macho
# =======================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-DPSDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

#================================================
# 1. Standard restrictions
#================================================

cat("\n---------------------------------------------------------------------------\n")
cat(" DPSDT-1: Parameter Information:\n")
cat("          - 4 models\n")   
cat("          - 6 response categories\n")
cat("          - Standard restrictions")
cat("\n---------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 4)
data <- rep(0, 6*cfg$n.sdt)
 
Par.Info <- SDT.Parameter.Info(data = data, Model.Id = "DPSDT", n = cfg)
print(Par.Info)

#================================================
# 2. Two-high threshold model
#================================================

cat("\n---------------------------------------------------------------------------\n")
cat(" DPSDT-2: Parameter Information:\n")
cat("          - 4 models\n")   
cat("          - 6 response categories\n")
cat("          - Restriction =\"standard-2\" (two-high threshold model)")
cat("\n---------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 4, restriction = "standard-2")
Par.Info <- SDT.Parameter.Info(data = data, Model.Id = "DPSDT", n = cfg)
print(Par.Info)

#====================================================================
# 3. Two-high threshold model with equal recollection probabilities
#====================================================================

cat("\n---------------------------------------------------------------------------\n")
cat(" DPSDT-3: Parameter Information:\n")
cat("          - 4 models\n")   
cat("          - 6 response categories\n")
cat("          - Restriction =\"standard-2-eq\" (two-high threshold model, equal p)")
cat("\n---------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 4, restriction = "standard-2-eq")
Par.Info <- SDT.Parameter.Info(data = data, Model.Id = "DPSDT", n = cfg)
print(Par.Info)

#===============================================================================
# 4. Pairs of single-high threshold models
#===============================================================================

cat("\n---------------------------------------------------------------------------\n")
cat(" DPSDT-4: Parameter Information:\n")
cat("          - 4 models\n")   
cat("          - 6 response categories\n")
cat("          - Restriction =\"standard-pairs\" (pairs of single-high\n") 
cat("            threshold models)")
cat("\n---------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 4, restriction = "standard-pairs")
Par.Info <- SDT.Parameter.Info(data = data, Model.Id = "DPSDT", n = cfg)
print(Par.Info)

#=================================================================================
# 5. Pairs of single-high threshold model with equal variance parameters for pairs
#=================================================================================

cat("\n---------------------------------------------------------------------------\n")
cat(" DPSDT-5: Parameter Information:\n")
cat("          - 4 models\n")   
cat("          - 6 response categories\n")
cat("          - Restriction =\"standard-pairs-eq\" (pairs of single-high\n") 
cat("            threshold models with variance parameters of pairs being equal)")
cat("\n---------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 4, restriction = "standard-pairs-eq")
Par.Info <- SDT.Parameter.Info(data = data, Model.Id = "DPSDT", n = cfg)
print(Par.Info)

#=================================================================================
# 6. Pairs of single-high threshold model with equal variance parameters for pairs
#=================================================================================

cat("\n---------------------------------------------------------------------------\n")
cat(" DPSDT-6: Parameter Information:\n")
cat("          - 4 models\n")   
cat("          - 6 response categories\n")
cat("          - Restriction =\"standard-pairs-eq\" (pairs of single-high\n") 
cat("            threshold models with variance parameters of pairs being equal)")
cat("\n---------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 4, restriction = "standard-pairs-eq")
Par.Info <- SDT.Parameter.Info(data = data, Model.Id = "DPSDT", n = cfg)
print(Par.Info)

#===============================================================================
# 7. Pairs of single-high threshold model with lures
#===============================================================================

cat("\n---------------------------------------------------------------------------\n")
cat(" DPSDT-7: Parameter Information:\n")
cat("          - 5 models: the first model represents lures\n")   
cat("          - 6 response categories\n")
cat("          - Restriction =\"standard-lure-pairs\" (pairs of single-high\n") 
cat("            threshold models with lure distribution)")
cat("\n---------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 5, restriction = "standard-lure-pairs")
data <- rep(0, 6*cfg$n.sdt)
Par.Info <- SDT.Parameter.Info(data = data, Model.Id = "DPSDT", n = cfg)
print(Par.Info)

#=================================================================================
# 8. Pairs of single-high threshold model with lures and equal varinaces for pairs
#=================================================================================

cat("\n---------------------------------------------------------------------------\n")
cat(" DPSDT-8: Parameter Information:\n")
cat("          - 5 models: the first model represents lures\n")   
cat("          - 6 response categories\n")
cat("          - Restriction =\"standard-lure-pairs-eq\" (pairs of single-high\n") 
cat("            threshold models with lure distribution and equal variances for\n)")
cat("            pairs other than the lure\n)")
cat("\n---------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 5, restriction = "standard-lure-pairs-eq")
Par.Info <- SDT.Parameter.Info(data = data, Model.Id = "DPSDT", n = cfg)
print(Par.Info)

#=================================================================================
# 9. SDT Model
#=================================================================================

cat("\n---------------------------------------------------------------------------\n")
cat(" DPSDT-9: Parameter Information:\n")
cat("          - 4 models:\n")   
cat("          - 6 response categories\n")
cat("          - Restriction =\"SDT\" (Unequal variance signal detection model") 
cat("\n---------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 4, restriction = "SDT")
data <- rep(0, 6*cfg$n.sdt)
Par.Info <- SDT.Parameter.Info(data = data, Model.Id = "DPSDT", n = cfg)
print(Par.Info)

#=================================================================================
# 10. Equal variance SDT Model
#=================================================================================

cat("\n---------------------------------------------------------------------------\n")
cat(" DPSDT-10: Parameter Information:\n")
cat("           - 4 models:\n")   
cat("           - 6 response categories\n")
cat("           - Restriction =\"SDT-EV\" (Equal variance signal detection model") 
cat("\n---------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 4, restriction = "SDT-EV")
data <- rep(0, 6*cfg$n.sdt)
Par.Info <- SDT.Parameter.Info(data = data, Model.Id = "DPSDT", n = cfg)
print(Par.Info)

