# ================================================================
# Examples of the documentation of Gaussian:
# Gauss-3: Illustration of the functional constraints
#	     Illustration of function SDT.Anova()	
#
# Date of last update: August, 2013
# Author: Siegfried Macho
# ================================================================

library(numDeriv)

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

n <- list(n.sdt = 4, restriction = "no")	 # Configuration list

# DATA RATCLIFF ET AL. (1994, Exp.1, 200 and 50 ms pure lists)
data <- c(477, 776, 527, 321, 258, 184,		# Pure Strong New 
	    192, 401, 290, 267, 316, 442,		# Pure Strong Old
	    235, 649, 719, 442, 254, 156,		# Pure Weak   New
	    151, 496, 480, 350, 221, 142)		# Pure Weak   Old

# CONSTRAINTS FOR ESTIMATING STRONG AND WEAK ITEMS SEPARATELY
fixed <- matrix(c(0, 1,  0,  1,
			1, 2, 15, 16), nr = 2, byrow = T)
ident <- matrix(c( 3:7,    (3:7)+14,
			(3:7)+7, (3:7)+21), nr = 2, byrow = T)

# FUNCTION PERFOMING FUNCTIONAL CONSTRAINT: s2 = 1.2*s4
fct.s <- function(par)
{
	tindex <- 2 + 7				# Target index: s2
	sindex <- 2 + 3*7				# Source index: 24

	par[tindex] <- 1.2 * par[sindex]

	# Define Gradient function
	gr.fct <- function(grad, par)
	{
		grad[sindex] <- grad[sindex] + 1.2 * grad[tindex]
		return(grad)
	}
	attr(par, "SDT.gradient") <- gr.fct			# Gradient
	return(par)
}

# FUNCTION COMPUTING THE JACOBIAN MATRIX CORRESPONDING TO FUNCTIONAL CONSTRAINTS
J.fct <- function(full.par)
{
      J <- diag(length(full.par))
      tindex <- 2 + 7
      sindex <- 2 + 3*7
      J[tindex, sindex] <- 1.2
      J
}
# PASS FUNCTION FOR COMPUTING THE JACOBIAN MATRIX AS AN ATTRIBUTE "Jacobian" TO THE FUNCTION
attr(fct.s, "SDT.Jacobian") <- J.fct

# ADD SPECIFIED PARAMETER TO FIXED ONES
fixed.func <- matrix(c(1, 2+7), nrow = 2, byrow = T)
fixed.s <- cbind(fixed, fixed.func)

Opti.Obj <- SDT.Estimate(data = data, Model.Id = "Gaussian", n = n, fixed = fixed.s, ident = ident, functional = fct.s, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)

cat("\n============================================================\n")
cat(" Gaussain: Result of the 4 group Gaussian model:")
cat("\n Strong and weak Items are estimated separately")
cat("\n NONLINEAR FUNCTIONAL CONSTRAINT: Stdev-2 = 1.2 * Stdev-4")
cat("\n============================================================\n")
print(Stat.Obj)

# COMPARE THE RESTRICTED WITH THE UNRESTRECTED MODEL
Opti2.Obj <- SDT.Estimate(data = data, Model.Id = "Gaussian", n = n, fixed = fixed, ident = ident, test = F)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)

cat("\n================================================================\n")
cat(" Comparison of models with and without functional constraints:")
cat("\n===============================================================\n")
print(SDT.Anova(Stat2.Obj, Stat.Obj))




