# ================================================================
# Examples of the documentation of Gaussian:
# Gauss-4.3:      Illustration of the function SDT.Estimate (4 signals)
#                 Computation of likelihood ratio confidence intervals
#
# Date of last update: August, 2013
# Author: Siegfried Macho
# ================================================================

library(numDeriv)

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

n <- 4				# NUMBER OF SIGNALS

# DATA RATCLIFF ET AL. (1994, Exp.1, 200 and 50 ms pure lists)
data <- c(477, 776, 527, 321, 258, 184,		# Pure Strong New 
	    192, 401, 290, 267, 316, 442,		# Pure Strong Old
	    235, 649, 719, 442, 254, 156,		# Pure Weak   New
	    151, 496, 480, 350, 221, 142)		# Pure Weak   Old


# ESTIMATE MODEL
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "Gaussian", n = n, test = T)

# EVALUTE THE RESULTS
Stat.Obj <- SDT.Statistics(Opti.Obj, control = list(LR = T))

# PRINT THE RESULTS
cat("\n=========================================\n")
cat(" Result of the 4 group Gaussian model:")
cat("\n=========================================\n")
print(Stat.Obj)

# NOW ESTIMATE MODELS FOR STRONG AND WEAK ITEMS SEPARATELY
n <- list(n.sdt = 4, restriction = "no")                    # New Configuration
fixed <- matrix(c(0, 1,  0,  1,
			1, 2, 15, 16), nr = 2, byrow = T)
ident <- matrix(c( 3:7,    (3:7)+14,
			(3:7)+7, (3:7)+21), nr = 2, byrow = T)

Opti.Obj <- SDT.Estimate(data = data, Model.Id = "Gaussian", n = n, fixed = fixed, ident = ident, test = T)
Stat2.Obj <- SDT.Statistics(Opti.Obj, control = list(LR = T))

cat("\n=======================================================\n")
cat(" Result of the 4 group Gaussian model:")
cat("\n Strong and weak Items are estimated separately")
cat("\n=======================================================\n")
print(Stat2.Obj)


# COMPARE THE RESTRICTED WITH THE UNRESTRECTED MODEL
cat("\n================================================================\n")
cat(" Comparison of models with simultaneous and separate fit:")
cat("\n===============================================================\n")
print(SDT.Anova(Stat2.Obj, Stat.Obj))