# ================================================================
# Examples of the documentation of the Gaussian model:
# Gauss-6: Illustration of underidentification 
#
# Date of last update: August, 2013
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

n <- list(n.sdt = 4, restriction = "no")		# CONFIGURATION LIST (NO RESTRICTIONS

# DATA RATCLIFF ET AL. (1994, Exp.1, 200 and 50 ms pure lists)
data <- c(477, 776, 527, 321, 258, 184,		# Pure Strong New 
	    192, 401, 290, 267, 316, 442,		# Pure Strong Old
	    235, 649, 719, 442, 254, 156,		# Pure Weak   New
	    151, 496, 480, 350, 221, 142)		# Pure Weak   Old

# ESTIMATE MODELS FOR STRONG AND WEAK ITEMS SEPARATELY WITHOUT CONSTRAINING
# THE MEAN OF DISTRIBUTION 3
fixed <- matrix(c(0, 1,  1,
			1, 2, 16), nr = 2, byrow = T)
ident <- matrix(c( 3:7,    (3:7)+14,
			(3:7)+7, (3:7)+21), nr = 2, byrow = T)

Opti.Obj <- SDT.Estimate(data = data, Model.Id = "Gaussian", n = n, fixed = fixed, ident = ident, test = T)

cat("\n=======================================================\n")
cat(" Demonstration of underidentification of parameters:")
cat("\n Problem: No location parameter fixed for weak items")
cat("\n Result of the 4 signal Gaussian model:")
cat("\n Strong and weak Items are estimated separately")
cat("\n=======================================================\n")
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)
