# ================================================================
# Examples of the documentation of the Gaussian model
# Gauss-7: Plotting configuration and ROCs with three signals
#
# Date of last update: August, 2013
# Autor: Siegfried Macho
# ================================================================

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# CONFIGURATION LIST: NUMBER OF MODELS = 3
cfg <- list(n.sdt = 3)

# CREATE START PARAMETER
par.vec <- SDT.Gaussian.start.par(6, cfg = cfg)
par.vec[8] <- 1                                 # Mean of 2. distribution
par.vec[15] <- 1.5                              # Mean of 3. distribution
par.vec[16] <- 2                                # Sd of 3. distribution

# Compute data from model
counts <- SDT.Gaussian(par.vec, cfg)

# PLOT CONFIGURATION USING A LIST WITH CONFIGURATION INFORMATION
Plot.Obj <- list(par = par.vec, n = cfg, Model.Id = "Gaussian", counts = counts)

# Plot Density functions
SDT.Plot(Plot.Obj, cols = c(3, 4, 6), labels = c("Memory Strength", "Density"), SDT.legend = list(text = c("New", "Weak", "Strong")))

# Plot ROC without data
SDT.Plot(Plot.Obj, cols = c(3, 4), labels = c("False Alarms", "Hits"), SDT.legend = list(pos = c(0.7, 0.2), text = c("Weak", "Strong")), option = "ROC")

# Plot ROC with data
SDT.Plot(Plot.Obj, cols = c(3, 4), labels = c("False Alarms", "Hits"), SDT.legend = list(pos = c(0.7, 0.2), text = c("Weak", "Strong")), option = "ROC+")

# Plot zROC without data
SDT.Plot(Plot.Obj, cols = c(3, 4), labels = c("False Alarms", "Hits"), SDT.legend = list(pos = c(1, -2), text = c("Weak", "Strong")), option = "zROC")

# Plot zROC with data
SDT.Plot(Plot.Obj, cols = c(3, 4), labels = c("False Alarms", "Hits"), SDT.legend = list(pos = c(1, -2), text = c("Weak", "Strong")), option = "zROC+")