# ================================================================
# Examples of the documentation of Model HT.n:
# HT.n-2.1: Associative recognition
# Data from Kelley & Wixted (2001)
# strong and weak items are estimted separately
# Date of creation: October, 2009
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-HT-n.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# DATA: Kelley & Wixted (2001, Exp.1 strong
# DATA OF KELLEY & WIXTED (2001), Experiment 1

data <- c(198, 148, 210,  85,  49,  30,   # Weak   Items, rearranged
	     72,  91, 167,  71,  71, 248,	# Weak   Items, intact
	    305, 110, 126,  79,  45,  55,	# Strong Items, rearranged
	     19,  23,  36,  57,  81, 504) 	# Strong Items, intact

n <- 2

#===============================================================================
#
# 1. HT.3 MODEL: WEAK AND STRONG ITEMS SEPARATELY
#
#===============================================================================

# Specification of constraints
fixed <- matrix(c(rep(0, 6), 0, 1, 5:7, 11:13, 8:9), nr = 2, byrow = T)
ident <- matrix(c(2:4, 16:14), nr = 2, byrow = T)

# Compute start parameter vector
par <- SDT.HT.n.start.par(n, data[1:12])

# Add redundant parameters so that ist position can be seen in output
fixed.show <- HT.n.Redundant.to.Fixed(par, n, fixed, ident)

# Compute Parameter information
Par.Info <- SDT.Parameter.Info(par = par, n = n, Model.Id = "HT.n", fixed = fixed.show, ident = ident)
cat("\n-------------------------------------------------------------\n")
cat("HT.3: Kelley & Wixted, Exp.1, Parameter-Information:")
cat("\n-------------------------------------------------------------\n")
print(Par.Info)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.3: Kelley & Wixted, Exp.1, weak items")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data[1:12], n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.3: Kelley & Wixted, Exp.1, strong items")
cat("\n------------------------------------------------------------------------------------\n")
Opti2.Obj <- SDT.Estimate(data = data[13:24], n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)
print(Stat2.Obj)

#===============================================================================
#
# 2. HT.2 MODEL: WEAK AND STRONG ITEMS SEPARATELY
#
#===============================================================================

# Specify additional fixed constraints: p3[1] = 0 (P 4) , p4[2] = 0 (P 14)
fixed.add <- matrix(c(0, 0, 
                      4, 14), nr = 2, byrow = T)
fixed <- cbind(fixed, fixed.add)

# Remove the equality constraint p3[1] = p4[2]
ident <- matrix(c(2:3, 16:15), nr = 2, byrow = T)

# Add redundant parameters so that ist position can be seen in output
fixed.show <- HT.n.Redundant.to.Fixed(par, n, fixed, ident)

# Compute Parameter information
Par.Info.HT.2 <- SDT.Parameter.Info(par = par, n = n, Model.Id = "HT.n", fixed = fixed.show, ident = ident)
cat("\n-------------------------------------------------------------\n")
cat("HT.2: Kelley & Wixted, Exp.1, Parameter-Information:")
cat("\n-------------------------------------------------------------\n")
print(Par.Info.HT.2)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.2: Kelley & Wixted, Exp.1, weak items")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data[1:12], n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.2: Kelley & Wixted, Exp.1, strong items")
cat("\n------------------------------------------------------------------------------------\n")
Opti2.Obj <- SDT.Estimate(data = data[13:24], n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)
print(Stat2.Obj)
