# ==============================================================================
# Ex.3: HTSDT-Bias-Rank model
#       Estimation of the ranking-rating model (ranking & rating, multiple models)
# Data: From an own experiment
#
# Date of creation: July, 2013
# Autor: Siegfried Macho
# ==============================================================================

# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
Dir  <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"
DirM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# Names of the source files required for estimating the data
NameS <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameM <- "HTSDT-Bias-Rank.R"

# Load source files
source(paste(Dir,  NameA, sep = ""))
source(paste(Dir,  NameS, sep = ""))
source(paste(DirM, NameM, sep = ""))

# Data 
datavec <- c(210,  68,  68,  54,            # Ranking 1, Target on Position 1
             193,  98,  60,  49,            # Ranking 1, Target on Position 2
             198, 101,  55,  46,            # Ranking 1, Target on Position 3
             169,  88,  82,  61,            # Ranking 1, Target on Position 4
             
             180,  79,  78,  63,            # Ranking 2, Target on Position 1
             184,  86,  85,  45,            # Ranking 2, Target on Position 2
             190, 100,  58,  52,            # Ranking 2, Target on Position 3
             185,  86,  74,  55)            # Ranking 2, Target on Position 4
             

#===============================================================================
# 1. Estimation of ranking data only
#===============================================================================
cfg <- list(k.rg = c(4, 4), rating = F)

ptm1 <- proc.time()

Opti1.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "HTSDT.Bias.Rank", test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat("Test 1: HTSDT-Bias-Model with ranking data from an own experiment\n")
cat("        2 ranking models <4, 4>\n")
cat("        Standard mixture model")
cat("\n-------------------------------------------------------------------------\n")
print(Stat1.Obj)

ptm2 <- proc.time()                       # Measuring time elapsed
tm <- time.estimate(ptm1, ptm2)
cat("\n=======================================================\n")
cat("Time required:\n")
cat(tm[1], "hours,", tm[2], "minutes,", tm[3], "seconds")
cat("\n=======================================================\n")

#===============================================================================
# 2. Estimation of ranking data only: Standard SDT model
#===============================================================================
cfg <- list(k.rg = c(4, 4), rating = F, restriction = "SDT")

Opti2.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "HTSDT.Bias.Rank", test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat("Test 2: HTSDT-Bias-Model with ranking data from an own experiment\n")
cat("        2 ranking models <4, 4>\n")
cat("        Standard SDT model")
cat("\n-------------------------------------------------------------------------\n")
print(Stat2.Obj)

ptm3 <- proc.time()                       # Measuring time elapsed
tm <- time.estimate(ptm2, ptm3)
cat("\n=======================================================\n")
cat("Time required (for standard SDT model):\n")
cat(tm[1], "hours,", tm[2], "minutes,", tm[3], "seconds")
cat("\n=======================================================\n")


#===============================================================================
# 3. Estimation of ranking data only: Extended mixture model
#===============================================================================
cfg <- list(k.rg = c(4, 4), rating = F, restriction = "EXTENDED")

Opti3.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "HTSDT.Bias.Rank", test = T)
Stat3.Obj <- SDT.Statistics(Opti3.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat("Test 3: HTSDT-Bias-Model with ranking data from an own experiment\n")
cat("        2 ranking models <4, 4>\n")
cat("        EXTENDED HTSDT model")
cat("\n-------------------------------------------------------------------------\n")
print(Stat3.Obj)

ptm4 <- proc.time()                       # Measuring time elapsed
tm <- time.estimate(ptm3, ptm4)
cat("\n=======================================================\n")
cat("Time required (for EXTENDED model):\n")
cat(tm[1], "hours,", tm[2], "minutes,", tm[3], "seconds")
cat("\n=======================================================\n")
