# ================================================================
# Ex.3: HTSDT-Rank model
# Estimation of the ranking-rating model
# Data: From the author
#
# Date of creation: June, 2013
# Autor: Siegfried Macho
# ================================================================
rm(list = ls())

# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
DirM  <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/Models/"
Dir   <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/"

# Names of the source files required for estimating the data
NameS <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameM <- "HTSDT-Rank.R"

# Load source files
source(paste(Dir,  NameA, sep = ""))
source(paste(Dir,  NameS, sep = ""))
source(paste(DirM, NameM, sep = ""))

# Data vector 
dvec <- c(2327, 873,                         # 1. 2-AFC data	
           739, 351, 295, 215)               # 2. 4-AFC data
           
T1 <- T           
T2 <- T           
T3 <- T           

#===============================================================================
# 1. Estimation of ranking data Standard restrictions
#===============================================================================
if(T1) {
   cfg <- list(j.rg = c(2, 4), rating = F)
   fixed <- matrix(c(0, 1, 1, 5), nr = 2)   # Recolletion = 0, Standard deviation of first model = 1

   Opti1.Obj <- SDT.Estimate(data = dvec, n = cfg, Model.Id = "HTSDT.Rank", fixed = fixed, test = T)
   Stat1.Obj <- SDT.Statistics(Opti1.Obj)			# Evaluate the results
   cat("\n-----------------------------------------------------\n")
   cat(" 1. Modeling (repeated) AFC data (2-AFC and 4-AFC)\n")
   cat("    Standard model\n")
   cat("    Additional restrictions (for identification):\n")
   cat("    - Recollection       of first model = 0\n")
   cat("    - Standard deviation of first model = 1")
   cat("\n-----------------------------------------------------\n")
   print(Stat1.Obj)
}
#===============================================================================
# 2. Estimation of ranking data: UVSDT model
#===============================================================================

if(T2) {
   cfg <- list(j.rg = c(2, 4), rating = F, restriction = "UVSDT")
   fixed <- matrix(c(1, 5), nr = 2)   # Standard deviation of first model to 1

   Opti2.Obj <- SDT.Estimate(data = dvec, n = cfg, Model.Id = "HTSDT.Rank", fixed = fixed, test = T)
   Stat2.Obj <- SDT.Statistics(Opti2.Obj)			# Evaluate the results
   cat("\n-----------------------------------------------------\n")
   cat(" 2. Modeling (repeated) AFC data (2-AFC and 4-AFC)\n")
  cat("     Additional restriction:\n")
   cat("    - Standard deviation of first model = 1")
   cat("\n-----------------------------------------------------\n")
   print(Stat2.Obj)
}

#===============================================================================
# 3. Estimation (repeated) AFC data: Equality restrictions
#===============================================================================

if(T3) {
   cfg <- list(j.rg = c(2, 4), rating = F, restriction = "equal")

   Opti3.Obj <- SDT.Estimate(data = dvec, n = cfg, Model.Id = "HTSDT.Rank", test = T)
   Stat3.Obj <- SDT.Statistics(Opti3.Obj)			# Evaluate the results
   cat("\n-----------------------------------------------------\n")
   cat(" 3. Modeling of ranking data (2-AFC and 4-AFC)\n")
   cat("    Equality restrictions")
   cat("\n-----------------------------------------------------\n")
   print(Stat3.Obj)
}