# ================================================================
# MIX-2.3: Examples of the documentation of Model MIX-2:
# Displaying parameter information: Data of Kelley & Wixted, Exp.2
#
# Date of creation: September, 2009
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-2.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# DATA OF KELLEY & WIXTED (2001), Experiment 2
data <- c(179, 109,  82,  45,  28,  37,   # Exp.2: Weak   Items, rearranged
	     81,  69,  62,  31,  37, 200,	# Exp.2: Weak   Items, intact
	    215,  82,  60,  31,  31,  61,	# Exp.2: Strong Items, rearranged
 	     21,  24,  33,  21,  33, 348,	# Exp.2: Strong Items, intact
	    879, 553, 345,  61,  54,  28)	# Exp.2: Lure items

# NUMBER OF CONDITIONS (TYPES OF SIGNALS)
n <- 5		

# GENERATE VECTOR OF STARTPARAMETERS
par <- SDT.MIX2.start.par(n, data)

# 1. SPECIFY FIXED CONSTRAINTS		
# 1.1 FIX PARAMETERS FOR THE LURE DISTRIBUTION: p.5 = 0, m.51 = m.52 = 0, sd.51 = sd.52 = 1  
#			    p.5 m.51 m.52 sd.51 sd.52
fixed.lure <- matrix(c( 0,   0,   0,    1,    1,
	   	           41,  42,  44,   43,   45), nr = 2, byrow = T)

# 1.2 FUNCTIONAL CONSTRAINTS ON MEANS (SEE BELOW)
#                     m.21 m.22 m.31 m.41 m.42
fixed.fct <- matrix(c(   0,   0,   0,   0,   0,
	   	            12,  14,  22,  32,  34), nr = 2, byrow = T)
# 1.3 COMBINE FIXED CONSTRAINTS
fixed <- cbind(fixed.lure, fixed.fct)


# 2. SPECIFY EQUALITY CONSTRAINTS: IDENTICAL PROBABILITIES AND THRESHOLD IDENTICAL
# 2.1 IDENTICAL THRESHOLDS
ident.th <- matrix(c(6:10,    6:10,    6:10,    6:10,
	   	      6:10+10, 6:10+20, 6:10+30, 6:10+40), nr = 2, byrow = T)

# 2.2 IDENTICAL SD FOR STRONG SIGNALS AND IDENTICAL SD FOR WEAK SIGNALS
ident.sd <- matrix(c(   3,    3,    3, 3+20, 3+20,  3+20,
	   	         3+10,    5, 5+10, 3+30, 5+20,  5+30), nr = 2, byrow = T)

# 2.3 COMBINE EQUALITY CONSTRAINTS
ident <- cbind(ident.th, ident.sd)

cat("\n---------------------------------------------------------------------\n")
cat(" MIX-2: Parameter information:")
cat("\n Model:Associative recognition (Data from Kelley and Wixted, Exp.2):")
cat("\n---------------------------------------------------------------------\n")
Par.Info <- SDT.Parameter.Info (data = data, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident)
print(Par.Info)

