# ================================================================
# MIX-2.5.1: Examples of the documentation of Model MIX.2:
# Modeling the mirror effect
#
# Model: DeCarlo (2007), Model 2
# Data: DeCarlo (2007)
#
# Date of creation: May, 2010
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-2.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# NUMBER OF SIGNALS
n <- 4

# DATA: DeCARLO (2007) Exp.1A: NATIVE SPEAKERS
data.1A <- c( 721, 1418, 1460,  860, 422,  159,        # High frequency New
             1457, 1436,  991,  567, 398,  191,        # Low frequency New
              211,  689, 1016, 1028, 894, 1202,        # High frequency Old
              233,  457,  568,  729, 995, 2058)        # Low frequency Old
              
              
# DATA: DeCARLO (2007) Exp.1B: NON-NATIVE SPEAKERS
data.1B <- c(740, 791, 616, 390, 230,  173,        # High frequency New
             899, 755, 504, 344, 236,  202,        # Low frequency New
             317, 449, 448, 374, 405,  947,        # High frequency Old
             215, 305, 309, 338, 478, 1295)        # Low frequency Old
              
                   
# 1. FIXED CONSTRAINTS		
# 1.1 FIX MEAN OF HIGH FREQUENCY NEW
fixed.m <- matrix(c(0, 0, 
                    2, 4), nr = 2, byrow = T)

# 1.2 FIX SD OF EACH OF THE 8 DISTRIBUTIONS TO 1.0
fixed.sd <- matrix(c(1, 1,  1,  1,  1,  1,  1,  1,
                     3, 5, 13, 15, 23, 25, 33, 35), nr = 2, byrow = T)

# 1.3 FIX PROBABILITY OF HIGH FREQUENCY NEW (TO AN ARBITRARY VALUE)
fixed.p <- matrix(c(0, 
                    1), nr = 2, byrow = T)

# 1.4 COMBINE FIXED CONSTRAINTS
fixed <- cbind(fixed.m, fixed.sd, fixed.p)


# 2. EQUALITY CONSTRAINTS: IDENTICAL THRESHOLDS FOR ALL SIGNALS
ident <- matrix(c(6:10,       6:10,    6:10,
	   	      6:10+10, 6:10+20, 6:10+30), nr = 2, byrow = T)

cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-2: DeCarlo (2007): Exp.1A:")
cat("\n------------------------------------------------------------------------------------\n")
Opti1A.Obj <- SDT.Estimate(data = data.1A, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident, test = T)
Stat1A.Obj <- SDT.Statistics(Opti1A.Obj)
print(Stat1A.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-2: DeCarlo (2007): Exp.1B:")
cat("\n------------------------------------------------------------------------------------\n")
Opti1B.Obj <- SDT.Estimate(data = data.1B, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident, test = T)
Stat1B.Obj <- SDT.Statistics(Opti1B.Obj)
print(Stat1B.Obj)

# 3. RE-FIT MODEL WITH ADDITIONAL CONSTRAINTS
# RESTRICTION: HN = HO' = LO' for Exp.1B
fixed.r <- matrix(c( 0,  0,
                     22, 32), nr = 2, byrow = T)
fixed <- cbind(fixed, fixed.r)

# RESTRICTION: HO = LO for Exp.2
ident.r <- matrix(c( 24,
                     34), nr = 2, byrow = T)
ident <- cbind(ident, ident.r)


cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-2: DeCarlo (2007): Exp.1B:\n")
cat(" Restrictions: HO' = LO' = HN\n")
cat("               HO  = LO")
cat("\n------------------------------------------------------------------------------------\n")
Opti1C.Obj <- SDT.Estimate(data = data.1B, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident, test = T)
Stat1C.Obj <- SDT.Statistics(Opti1C.Obj)
print(Stat1C.Obj)

# PLOT DENSITY CURVES OF EXP.1A
SDT.Plot(Opti1A.Obj, cols = rep(1:4, each = 2), ltys = rep(c(1,2), 4), 
SDT.legend = list(text = c("HF", "LF New", "HF Old", "LF Old"), cols = 1:4, ltys = rep(1, 4)))

# PLOT ROC CURVES
# ROC with data
SDT.Plot(Opti1A.Obj, cols = c(3, 4, 6), 
SDT.legend = list(text = c("LF New", "HF Old", "LF Old"), cols = c(3, 4, 6)), option = "ROC+")

# z-ROC with data
SDT.Plot(Opti1A.Obj, cols = c(3, 4, 6), 
SDT.legend = list(text = c("LF New", "HF Old", "LF Old"), cols = c(3, 4, 6)), option = "zROC+")
