# ================================================================
# Examples of the documentation of MIX.2: Plot functions
# MIX-2.6.2: Plotting MIX.2 Model and data of Associative Recognition
#
# Model: DeCarlo (2007), Model 2
# Data: DeCarlo (2007)
#
# Date of creation: July, 2010
# Autor: Siegfried Macho
# ================================================================

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-2.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# NUMBER OF SIGNALS
n <- 5

# DATA OF KELLEY & WIXTED (2001), Experiment 2
data <- c(879, 553, 345,  61,  54,  28,	# Exp.2: Lure items
          179, 109,  82,  45,  28,  37,   # Exp.2: Weak   Items, rearranged
	     81,  69,  62,  31,  37, 200,	# Exp.2: Weak   Items, intact
	    215,  82,  60,  31,  31,  61,	# Exp.2: Strong Items, rearranged
 	     21,  24,  33,  21,  33, 348)	# Exp.2: Strong Items, intact

# ESTIMATED PARAMETER-VECTOR
par.vec <-  c( 0.0000000,  0.0000000, 1.0000000, 0.0000000, 1.0000000, -0.1078434, 0.6754557, 1.4018938, 1.7458245, 2.1873065,  # Signal 1
              -2.2133346, -2.2111884, 1.2375336, 0.5085118, 1.2375336, -0.1078434, 0.6754557, 1.4018938, 1.7458245, 2.1873065,  # Signal 2
              -0.1546352,  3.2282121, 1.2375336, 0.5085118, 1.2375336, -0.1078434, 0.6754557, 1.4018938, 1.7458245, 2.1873065,  # Signal 3
              -0.8198382, -1.8700792, 1.4752776, 0.8496211, 1.4752776, -0.1078434, 0.6754557, 1.4018938, 1.7458245, 2.1873065,  # Signal 4
               1.6792105,  3.5693214, 1.4752776, 0.8496211, 1.4752776, -0.1078434, 0.6754557, 1.4018938, 1.7458245, 2.1873065)  # Signal 5

# PLOT CONFIGURATION USING A LIST WITH CONFIGURATION INFORMATION
Plot.Obj <- list(par = par.vec, n = n, Model.Id = "MIX.2", counts = data)

# Plot Density functions
SDT.Plot(Plot.Obj, cols = c(6, 6, 3, 3, 3, 3, 4, 4, 4, 4), SDT.legend = list(text = c("New", paste("Weak", 1:3),paste("Strong", 1:3)), cols =c(6, 3, 3, 3, 4, 4, 4)))

# Plot ROC without data
SDT.Plot(Plot.Obj, cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1), labels = c("False Alarms", "Hits"), option = "ROC",
SDT.legend = list(text = c("weak rearranged", "weak intact","strong rearranged", "strong intact"), cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1)))

# Plot ROC with data
SDT.Plot(Plot.Obj, cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1), labels = c("False Alarms", "Hits"), option = "ROC+",
SDT.legend = list(text = c("weak rearranged", "weak intact","strong rearranged", "strong intact"), cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1)))

# Plot zROC without data
SDT.Plot(Plot.Obj, cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1), labels = c("False Alarms", "Hits"), option = "zROC",
SDT.legend = list(text = c("weak rearranged", "weak intact","strong rearranged", "strong intact"), cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1)))

# Plot zROC with data
SDT.Plot(Plot.Obj, cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1), labels = c("False Alarms", "Hits"), option = "zROC+",
SDT.legend = list(text = c("weak rearranged", "weak intact","strong rearranged", "strong intact"), cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1)))