# ================================================================
# Examples of the documentation of Model MIX.PD:  Plot functions
# MIX.PD.4-2: Plot of Density and ROC curves 
#
# Data: Hilford et al. (2002), Exp.3: Source monitoring with 2 signals
#
# Date of creation: July, 2010
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-PD.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# NUMBER OF SIGNALS
n <- 2

# DATA: HILFORD ET AL. (2002), Exp.3
data <- c(1313, 538, 524, 529, 363,  333,		# Top 
           348, 356, 455, 552, 510, 1379)		# Bottom
 	       
# VECTOR OF ESTIMATED PARAMETERS
par.vec <- c(-0.53456675, -0.53456675,  1.74495692,  1.74495692, 
             -1.05540387, -0.52454506, -0.03075355,  0.51315674,  1.03088703)


# PLOT CONFIGURATION OF DENSITY CURVES AND ROC CURVES USING A LIST WITH CONFIGURATION INFORMATION
Plot.Obj <- list(par = par.vec, n = n, Model.Id = "MIX.PD", counts = data)

# Plot Density functions
SDT.Plot(Plot.Obj, cols = c(3, 4, 6), SDT.legend = list(text = c("no info", "left",  "right")))

# Plot ROC without data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "ROC")

# Plot ROC with data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "ROC+")

# Plot zROC without data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "zROC")

# Plot zROC with data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "zROC+")
