# ====================================================================
# SDT-2D-1-1: Example of the SDT-2D MODEL
#             Thomas, R. D. (2001). Characterizing perceptual interactions in 
#		  face identification using multidimensional signal detection theory. 
#		  In M. J. Wenger, & J. T. Townsend (Eds.), 
#		  Computational geometry, and processing perspectives on facial cognition
#		  (Chapter 6, pp. 193-227). Hillsdale, NJ: Erlbaum. 
#
# Data:	  Observer A (p.212, Table, 6.1)
# Results:	  p. 220, Table 7.
#
# Author:     Siegfried Macho
# Date of last update: September, 2013
# ====================================================================

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT-2D.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT-2D MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# CONFIGURATION OF THE MODEL:
#------------------------------------------------------------------
# Restrictions:   st = standard restrictions
#                 v1 = all variances equal to 1
#                 er = equal correlation coefficients
#                 qu = quadratic setup (rectangular configuration)
#------------------------------------------------------------------
cfg <- list(n.sdt = 4, k1 = 1, k2 = 1, ds = 0, restriction = "st-v1-er-qu")

# DATA FROM THOMAS (2001)
data <- c(  83, 112,  47,  11,
            38, 154,  28,  33,
            15,  27, 117,  94,
             6,  36,  75, 136)

# PRINT PARAMETER INFORMATION
p.info <- SDT.Parameter.Info(n = cfg, Model.Id = "SDT.2D")
cat("\n==============================================")
cat("\n Parameter information:")
cat("\n==============================================\n")                     
print(p.info)

# CALL ESTIMATION MODULE AND PRINT THE RESULT
Opti.obj <- SDT.Estimate(data = data, n = cfg, Model.Id = "SDT.2D", test = T)

# COMPUTE AND PRINT STATISTICS
Stat.Obj <- SDT.Statistics(Opti.obj)
cat("\n==============================================")
cat("\n Result of the Estimation: Thomas (2001):")
cat("\n==============================================\n")
print(Stat.Obj)

# PLOT CONFIGURATION
xy.labels <- c("Eyes", "Nose")
SDT.Plot(Opti.obj, cols = 3:6, labels = xy.labels)