# =============================================================
# SDT-2D-12: Example of the SDT-2D MODEL
#            Estimation of data from Rotelo et al (2005)
#            - Decisional separability assumed
#            - Pooling of data
#            - Robust estimation of decision bounds
#
# Author: Siegfried Macho
# Date of last update: September, 2013
# =============================================================
library(ellipse)

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"


# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT-2D.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT-2D MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# INPUT DATA FILE: Rotelo et al (2005), netural condition 
#               Lure  Target
data <- matrix(c(745, 290,	# 1  New
                  46,  26,	# 2  Remember 2
                  29,  38,	# 3  Remember 3
                  47,  61,	# 4  Remember 4
                  51, 109,	# 5  Remember 5
                  55, 433,	# 6  Remember 6
                 199, 122,	# 7  Know 2
                   0,	0,	# 8  Remember 2
                   0,   0,	# 9  Remember 3
                   0,	0,	# 10 Remember 4
                   0,	0,	# 11 Remember 5
                   0,	0,	# 12 Remember 6
                 124, 106,	# 13 Know 3
                   0,	0,	# 14 Remember 2
                   0,	0,	# 15 Remember 3
                   0,	0,	# 16 Remember 4
                   0,	0,	# 17 Remember 5
                   0,	0,	# 18 Remember 6
                  84, 101,	# 19 Know 4
                   0,	0,	# 20 Remember 2
                   0,	0,	# 21 Remember 3
                   0,	0,	# 22 Remember 4
                   0,	0,	# 23 Remember 5
                   0,	0,	# 24 Remember 6
                  45,  92,	# 25 Know 5
                   0,	0,	# 26 Remember 2
                   0,	0,	# 27 Remember 3
                   0,	0,	# 28 Remember 4
                   0,	0,	# 29 Remember 5
                   0,	0,	# 30 Remember 6
                  13,  59,	# 31 Know 6
                   0,	0,	# 32 Remember 2
                   0,	0,	# 33 Remember 3
                   0,	0,	# 34 Remember 4
                   0,	0,	# 35 Remember 5
                   0,	0	# 36 Remember 6
                   ), nc = 2, byrow = T)

data <- c(data[,1], data[,2])           # Make data vector

# SPECIFICATION OF MATRIX R FOR POOLING DATA: Source cells in columns, target cells in rows
R <- diag(length(data))

# Specify relevant entries for the lure signal
C2 <- c(8, 14, 20, 26, 32)
C3 <- C2 + 1
C4 <- C2 + 2
C5 <- C2 + 3
C6 <- C2 + 4

R[2, C2]   <- 1
R[3, C3]   <- 1
R[4, C4]   <- 1
R[5, C5]   <- 1
R[6, C6]   <- 1

# Specify relevant entries for the target signal
C22 <- C2 + 36
C23 <- C3 + 36
C24 <- C4 + 36
C25 <- C5 + 36
C26 <- C6 + 36
R[2+36, C22]   <- 1
R[3+36, C23]   <- 1
R[4+36, C24]   <- 1
R[5+36, C25]   <- 1
R[6+36, C26]   <- 1

# Delete rows of the cells that are grouped together
R <- R[-c(C2, C3, C4, C5, C6, C22, C23, C24, C25, C26),]

# CONFIGURATION OF THE MODEL
cfg <- list(n.sdt = 2, k1 = 5, k2 = 5, ds = 0, R = R, robust = T)

# SPECIFICATION OF FIXED CONSTRAINTS: Standard deviation to 1
fixed.par <-matrix(c(0, 0,
                     5, 10), nrow = 2, byrow = T)  

# NO EQUALITY CONSTRAINTS
equal.par <- NULL

# PRINT PARAMETER INFORMATION
p.info <- SDT.Parameter.Info(data = data, n = cfg, Model.Id = "SDT.2D", fixed = fixed.par, ident = equal.par)
cat("\n==============================================\n")
cat(" Parameter information (Serial Model):")
cat("\n==============================================\n")                     
print(p.info)

# CALL ESTIMATION MODULE AND PRINT THE RESULT
Opti.obj <- SDT.Estimate(data = data, n = cfg, Model.Id = "SDT.2D", fixed = fixed.par, ident = equal.par, test = T)

# COMPUTE AND PRINT STATISTICS
Stat.Obj <- SDT.Statistics(Opti.obj)
cat("\n=========================================================\n")
cat(" Results for the data neutral condition (Seriall model):")
cat("\n==========================================================\n")
print(Stat.Obj)

# PLOT CONFIGURATION
xy.labels <- c("Familiarity", "Recollection")
SDT.Plot(Opti.obj, cols = 3:6, labels = xy.labels, option = 6:30)