# =============================================================
# SDT-2D-2-2: Example of the SDT-2D MODEL
#             Estimation of data from Olzak & Kramer (1984)
#             - Decisional separability assumed
#             - structural zeros present
#             - Robust estimation
#
# Author: Siegfried Macho
# Date of last update: September, 2013
# =============================================================
library(ellipse)

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"
DirData <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/Data/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT-2D.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# NAME OF THE DATA FILE
Data <- "Daten (Wickens, 1992).txt"

# LOAD SOURCE FILES WITH SDT-2D MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# LOAD DATA
data <- read.table(paste(DirData, Data, sep = ""), header = T)
data <- c(data[,3], data[,4], data[,5], data[,6])

# CONFIGURATION OF THE MODEL
#------------------------------------------------------------------
# Restrictions:   st   = standard restrictions
#                 quvd = quadratic setup (rectangular configuration)
#                        + dimensionwise equal variances 
#------------------------------------------------------------------
cfg <- list(n.sdt = 4, k1 = 5, k2 = 5, struct.zero = c(1, 36+1, 2*36+1, 3*36+1), robust = T, restriction = "st-quvd")

# PRINT PARAMETER INFORMATION
p.info <- SDT.Parameter.Info(n = cfg, Model.Id = "SDT.2D")
cat("\n==============================================\n")
cat(" Parameter information:")
cat("\n==============================================\n")                     
print(p.info)

# CALL ESTIMATION MODULE AND PRINT THE RESULT
Opti.obj <- SDT.Estimate(data = data, n = cfg, Model.Id = "SDT.2D", test = T)

# COMPUTE AND PRINT STATISTICS
Stat.Obj <- SDT.Statistics(Opti.obj)
cat("\n==================================================\n")
cat(" Results for the data of Olzak and Kramer (1984):")
cat("\n==================================================\n")
print(Stat.Obj)

# PLOT CONFIGURATION
xy.labels <- c("Low Frequency Signal", "High Frequency Signal")
SDT.Plot(Opti.obj, cols = 3:6, labels = xy.labels)