# =============================================================
# SDT-2D-8-1:     Example of the SDT-2D MODEL
#                 Estimation of polychiric coerrelation
#                 Data from Finney & DiStefano, 2006
#
# Author: Siegfried Macho
# Date of last update: September, 2013
# =============================================================
library(ellipse)

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT-2D.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT-2D MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# LOAD DATA
data <- c(2, 1, 1, 0, 0, 8, 6, 2, 1, 15, 26, 8, 1, 3, 9, 37)

# CONFIGURATION OF THE MODEL
cfg <- list(n.sdt = 1, k1 = 3, k2 = 3)

# CALL ESTIMATION MODULE AND PRINT THE RESULT
Opti.obj <- SDT.Estimate(data = data, n = cfg, Model.Id = "SDT.2D", test = T)

# COMPUTE AND PRINT STATISTICS
Stat.Obj <- SDT.Statistics(Opti.obj)
cat("\n==================================================\n")
cat(" Results for the data of Olzak and Kramer (1984):")
cat("\n==================================================\n")
print(Stat.Obj)

# PLOT CONFIGURATION
xy.labels <- c("Satisfaction", "Quality")
SDT.Plot(Opti.obj, cols = 3:6, labels = xy.labels)
