# =============================================================
# SDT-2D-9-1: Example of the SDT-2D MODEL
#             Estimation of data from Olzak & Kramer (1984)
#             - Decisional separability assumed
#             - Pooling of data
#
# Author: Siegfried Macho
# Date of last update: September, 2013
# =============================================================
library(ellipse)

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"
DirData <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/Data/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT-2D.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# NAME OF THE DATA FILE
Data <- "Daten (Wickens, 1992).txt"

# LOAD SOURCE FILES WITH SDT-2D MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# LOAD DATA
data <- read.table(paste(DirData, Data, sep = ""), header = T)
data <- c(data[,3], data[,4], data[,5], data[,6])

# SPECIFICATION OF A MATRIX FOR POOLING DATA
R <- diag(length(data))
group.1 <- c(2, 7, 8)         # Cells which are pooled with the target cells
group.2 <- c(2, 7, 8) + 36
group.3 <- c(2, 7, 8) + 36*2
group.4 <- c(2, 7, 8) + 36*3

target.1  <- 1                # Target cells
target.2  <- 1 + 36
target.3  <- 1 + 36*2
target.4  <- 1 + 36*3

# Matrix: Source cells in columns, target cells in rows
R[target.1, group.1] <- 1
R[target.2, group.2] <- 1
R[target.3, group.3] <- 1
R[target.4, group.4] <- 1

# Delete rows of cells that are grouped
R <- R[-c(group.1, group.2, group.3, group.4),]

# CONFIGURATION OF THE MODEL
cfg <- list(n.sdt = 4, k1 = 5, k2 = 5, ds = 0, R = R, restriction = "st-quvd")

# PRINT PARAMETER INFORMATION
p.info <- SDT.Parameter.Info(n = cfg, Model.Id = "SDT.2D")
cat("\n==============================================\n")
cat(" Parameter information:")
cat("\n==============================================\n")                     
print(p.info)

# CALL ESTIMATION MODULE AND PRINT THE RESULT
Opti.obj <- SDT.Estimate(data = data, n = cfg, Model.Id = "SDT.2D", test = T)

# COMPUTE AND PRINT STATISTICS
Stat.Obj <- SDT.Statistics(Opti.obj)
cat("\n==================================================\n")
cat(" Results for the data of Olzak and Kramer (1984):")
cat("\n==================================================\n")
print(Stat.Obj)

# PLOT CONFIGURATION
xy.labels <- c("Low Frequency Signal", "High Frequency Signal")
SDT.Plot(Opti.obj, cols = 3:6, labels = xy.labels)