# ================================================================
# Examples of the documentation of SDT:
# SDT-3.1: Illustration of the functional constraints
#
# Date of last update: August, 2013
# Author: Siegfried Macho
# ================================================================

library(numDeriv)

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

n <- 4				# NUMBER OF SIGNALS

# DATA RATCLIFF ET AL. (1994, Exp.1, 200 and 50 ms pure lists)
data <- c(477, 776, 527, 321, 258, 184,		# Pure Strong New 
	    192, 401, 290, 267, 316, 442,		# Pure Strong Old
	    235, 649, 719, 442, 254, 156,		# Pure Weak   New
	    151, 496, 480, 350, 221, 142)		# Pure Weak   Old

# FUNCTION PERFOMING FUNCTIONAL CONSTRAINT: s2 = 1.2*s4
fct.s <- function(par)
{
	tindex <- 2				# Target index: s2
	sindex <- 6				# Source index: s4

	par[tindex] <- 1.2 * par[sindex]

	# Define Gradient function
	gr.fct <- function(grad, par)
	{
		grad[sindex] <- grad[sindex] + 1.2 * grad[tindex]
		return(grad)
	}
	attr(par, "SDT.gradient") <- gr.fct			# Gradient
	return(par)
}

# FUNCTION COMPUTING THE JACOBIAN MATRIX CORRESPONDING TO FUNCTIONAL CONSTRAINTS
J.fct <- function(full.par)
{
      J <- diag(length(full.par))
      tindex <- 2
      sindex <- 6
      J[tindex, sindex] <- 1.2
      J
}
# PASS FUNCTION FOR COMPUTING THE JACOBIAN MATRIX AS AN ATTRIBUTE "Jacobian" TO THE FUNCTION
attr(fct.s, "SDT.Jacobian") <- J.fct

# ADD SPECIFIED PARAMETER TO FIXED ONES
fixed <- matrix(c(1, 2), nrow = 2, byrow = T)

# ESTIMATE MODEL
Opti.Obj <- SDT.Estimate(data = data, n = n, fixed = fixed, functional = fct.s, test = T)

# EVALUTE THE RESULTS
Stat.Obj <- SDT.Statistics(Opti.Obj)

# PRINT THE RESULTS
cat("\n===========================================================\n")
cat(" SDT: Result of the 4 group SDT model:")
cat("\n NONLINEAR FUNCTIONAL CONSTRAINT: Stdev-2 = 1.2 * Stdev-4")
cat("\n===========================================================\n")
print(Stat.Obj)


