# ===========================================================================
# Examples of the documentation of Gaussian:
# SDT-3.2: Illustration of functional constraints: symmtric thresholds
#	     Functional constraint: t3 - t2 = t4 - t3
#                                 t3 - t1 = t5 - t3
#  
# Date last update: August 2013
# Author: Siegfried Macho
# ===========================================================================

library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))


# DATA OF RATCLIFF ET AL. (1994, Exp.1, 200 ms pure strong list)
data <- c(477, 776, 527, 321, 258, 184,			# New
	    192, 401, 290, 267, 316, 442)			# Old

# SET FIXED CONSTRAINTS (CORRESPONDING TO PARAMETERS SUBJECTED TO FUNCTIONAL CONSTRAINTS
fixed <- matrix(c(0, 0, 6, 7),   nr = 2, byrow = T)	# Fix standard deviation of first distribution and include functional constraint


# FUNCTION PERFOMING FUNCTIONAL CONSTRAINT ON THRESHOLDS: 
#     t3 - t2 = t4 - t3  
#     t3 - t1 = t5 - t3 
fct.m <- function(par)
{
	t.1 <- 3				# Position of decision bound 1
	t.2 <- 4				# Position of decision bound 2
	t.3 <- 5                      # Position of decision bound 3
	t.4 <- 6                      # Position of decision bound 4
	t.5 <- 7                      # Position of decision bound 5

	par[t.4] <- 2*par[t.3] - par[t.2]
	par[t.5] <- 2*par[t.3] - par[t.1]
	

	# Define Gradient function
	gr.fct <- function(grad, par)
	{
		grad[t.3] <- grad[t.3] + 2*grad[t.4] + 2*grad[t.5]
		grad[t.2] <- grad[t.2] - grad[t.4]
		grad[t.1] <- grad[t.1] - grad[t.5]
		return(grad)
	}
	attr(par, "SDT.gradient") <- gr.fct			# Gradient

	return(par)
}

# FUNCTION COMPUTING THE JACOBIAN MATRIX CORRESPONDING TO FUNCTIONAL CONSTRAINTS
J.fct <- function(full.par)
{
      J <- diag(length(full.par))
      J[6, 5] <-  2
      J[7, 5] <-  2
      J[6, 4] <- -1
      J[7, 3] <- -1
      J
}      
# PASS FUNCTION FOR COMPUTING THE JACOBIAN MATRIX AS AN ATTRIBUTE "Jacobian" TO THE FUNCTION
attr(fct.m, "SDT.Jacobian") <- J.fct			       


Opti.Obj <- SDT.Estimate(data = data, fixed = fixed, functional = fct.m, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
print(Stat.Obj)


