# ================================================================
# SDT-IRF-Gauss 2: Fitting models to data (3 tpyes of signals)
# Data:  Ratcliff et al. 1994, Exp.1 mixed lists
#
# Date of last update: May, 2019
# Author: Siegfried Macho
# ================================================================
# LIBRARY REQUIRED SINCE THE TESTFLAG IN ESTIMATION PROCEDURE IS SET TO TRUE
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/"
DirSourceM <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-IRF-Gauss.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH MODEL AS WELL AS AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSourceM, Model, sep = ""))
source(paste(DirSource,  Auxiliary, sep = ""))
source(paste(DirSource,  Main, sep = ""))


# DATA OF RATCLIFF ET AL. (1994, Exp.1, mixed lists)
datavec <- c(788, 1585, 1160, 656, 555, 299,   # New
             261,  551,  414, 280, 223, 165,   # Mixed weak
             172,  355,  345, 283, 308, 432)   # Mixed strong


# FIT SDT-GRM MODEL AND COMPUTE OUTPUT
cfg <- list(n.sdt = 3, model = "GRM")
Opti.GRM <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "IRF.Gauss", test = T)
Stat.GRM <- SDT.Statistics(Opti.GRM)

# FIT SDT-ORM MODEL AND COMPUTE OUTPUT
cfg <- list(n.sdt = 3, model = "ORM")
Opti.ORM <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "IRF.Gauss", test = T)
Stat.ORM <- SDT.Statistics(Opti.ORM)

# PRINT THE RESULTS
cat("\n-----------------------------------------------------------------------\n")
cat(" Results of the GRM-SDT (Graded Response) model:\n")
cat(" Data: Ratcliff, MacKoon, & Tindall, 1994, Exp.1, mixed lists")
cat("\n-----------------------------------------------------------------------\n")
print(Stat.GRM)
cat("\n-----------------------------------------------------------------------\n")
cat(" Results of the ORM-SDT (Ordinal Rasch) model:\n")
cat(" Data: Ratcliff, MacKoon, & Tindall, 1994, Exp.1, mixed lists")
cat("\n-----------------------------------------------------------------------\n")
print(Stat.ORM)
