#===============================================================================
# Ex.1 Rank-SDT model: 
#      Estimation of pure AFC or ranking data for two data sets
#
# Date of creation:       December, 2014
# Date of last Update:    November, 2020
#
# Autor: Siegfried Macho
#===============================================================================
rm(list = ls())

Dir  <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/"
DirM <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

Name  <- "SDT-Rank.R"
NameM <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
source(paste(Dir, NameM, sep = ""))
source(paste(Dir, NameA, sep = ""))
source(paste(DirM, Name, sep = ""))

# DATA FROM AN OWN EXPERIMENT
data.org <- c(518, 157, 118, 107,	# parallel, target in 1. position
	            537, 148, 135, 80,	# parallel, target in 2. position
	            517, 178, 127, 78,  # parallel, target in 3. position
              507, 164, 122, 107, # parallel, target in 4. position

	            509, 152, 142, 97,  # serial, target in 1. position
	            545, 186, 102, 67,  # serial, target in 2. position
	            516, 162, 127, 95,	# serial, target in 3. position
	            497, 164, 123, 121)	# serial, target in 4. position

# POOL THE DATA FROM THE DIFFERENT POSITIONS
datavec <- c(data.org[1:4]   + data.org[5:8]   + data.org[9:12]  + data.org[13:16],
             data.org[17:20] + data.org[21:24] + data.org[25:28] + data.org[29:32])

cfg.1 <- list(k.rg = c(4, 4), rating = F)
cfg.2 <- list(k.rg = c(4, 4), rating = F, restriction = "equal")


#===============================================================================
# 1. Estimation of ranking data: 
#    4-AFC & 3-AFC
#    Standard UVSDT restrictions
#===============================================================================
Opti.Obj <- SDT.Estimate(data = datavec, n = cfg.1, Model.Id = "SDT.Rank", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat("Results of estimation of 4-AFC & 3-AFC data with standard restrictions:")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)

#===============================================================================
# 2. Estimation of ranking data: 
#    4-AFC & 3-AFC
#    Equality restrictions
#===============================================================================
Opti.Obj <- SDT.Estimate(data = datavec, n = cfg.2, Model.Id = "SDT.Rank", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat("Results of estimation of 4-AFC & 3-AFC data with equality restrictions:")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)
