# ================================================================
# Ex.3: SDT-Rank model:
# Estimation of the ranking-rating model
# Data: Kellen Klauer and Singmann(2012)
#
# Date of creation:    February, 2013
# Date of last update: November, 2020
# Autor: Siegfried Macho
# ================================================================
rm(list = ls())

# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
Dir  <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/"
DirM <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# Names of the source files required for estimating the data
NameM <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameR <- "SDT-Rank.R"
NameS <- "SDT-SDT.R"

# Load source files
source(paste(Dir,  NameM, sep = ""))
source(paste(Dir,  NameA, sep = ""))
source(paste(DirM, NameR, sep = ""))
source(paste(DirM, NameS, sep = ""))

# Data vector of Kellen, Klauer & Singmann (2012), pooled data
datavec <- c(1801, 488, 407, 304,                 # 1. Ranking data
              667, 780, 651, 485, 277,  140,      # 2. Rating data (new)
              198, 303, 402, 421, 426, 1250)      # 3. Rating data (old)

#===============================================================================
# 1. Estimation of ranking data only
#===============================================================================
cfg <- list(k.rg = 4, rating = F)

Opti.Obj <- SDT.Estimate(data = datavec[1:4], n = cfg, Model.Id = "SDT.Rank", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat("1. Results of Kellen, Klauer & Singmann, 2012: ranking data only")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)

#===============================================================================
# 2. Estimation of rating data
#===============================================================================
Opti.Obj <- SDT.Estimate(data = datavec[5:16], test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat("2. Results of Kellen, Klauer & Singmann, 2012: Rating data only")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)

#===============================================================================
# 2. Estimation of both ranking and rating data
#===============================================================================
cfg <- list(k.rg = 4, rating = T)
cfg <- list(k.rg = 4, rating = T, restriction = "equal")


Opti.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "SDT.Rank", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat("3. Results of Kellen, Klauer & Singmann, 2012: ranking and rating data")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)