# ================================================================
# Ex.4: SDT-Rank model:
# Estimation of the ranking model
# Data: Kellen et al. (2012)
#
# Date of creation: October 2020
# Autor: Siegfried Macho
# ================================================================
rm(list = ls())

# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
Dir  <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/"
DirM <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# Names of the source files required for estimating the data
NameS <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameM <- "SDT-Rank.R"

# Load source files
source(paste(Dir,  NameA, sep = ""))
source(paste(Dir,  NameS, sep = ""))
source(paste(DirM, NameM, sep = ""))

# Data vector of Kellen, Klauer & Singmann (2012), pooled data
datavec <- c(1801, 488, 407, 304,                 # 1. Ranking data
              667, 780, 651, 485, 277,  140,      # 2. Rating data (new)
              198, 303, 402, 421, 426, 1250)      # 3. Rating data (old)

#===============================================================================
# 1. Estimation of non-repeated 4-AFC data
#===============================================================================

# identification restrictions: Fix satnadr deviation to 1
fixed <- matrix(c(1, 4), nc = 1)

cfg <- list(k.rg = 4, j.rg = 2, rating = F)
Opti.Obj <- SDT.Estimate(data = c(datavec[1], sum(datavec[2:4])), n = cfg, Model.Id = "SDT.Rank", fixed = fixed, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results

cat("\n-------------------------------------------------------------------------\n")
cat("1. Results of Kellen, Klauer & Singmann, 2012: 4-AFC data, non-repeated")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)


#===============================================================================
# 2. Estimation of both ranking and rating data
#===============================================================================
cfg <- list(n.sdt = c(2, 6), k.rg = 4, j.rg = 2, rating = T, restriction = "equal")

# Combine ranking data from Rank 2 to 4
dvec <- c(datavec[1], sum(datavec[2:4]), datavec[5:16])
Opti.Obj <- SDT.Estimate(data = dvec, n = cfg, Model.Id = "SDT.Rank", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat("2. Results of Kellen, Klauer & Singmann, 2012:\n")
cat("   Ranking and non-repated rating data (only first rank relevant)")
cat("   Equality restrictions")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)